/*  
	$Id: configwin.c,v 1.8 2003/09/06 02:16:47 Treize Exp $
	ROX-Menu - A simple application menu applet for ROX desktop environment.
	Copyright (C) 2001 Leandro Pereira <leandro@linuxmag.com.br>
	Copyright (C) 2003  Peter Geer <geerp@cs.sunyit.edu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "configwin.h"
#include <stdio.h>

GtkWidget *height_spin = NULL;
GtkWidget *width_spin = NULL;
GtkWidget *icon_path_on_box = NULL;
GtkWidget *icon_path_off_box = NULL;
GtkWidget *group_check = NULL;
GtkWidget *strip_check = NULL;

static void update_config(void) {
	icon_height = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(height_spin));
	icon_width = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(width_spin));
	
	g_free(menu_file_on);
	g_free(menu_file_off);
	/* The g_strdup() here is to suppress compiler warnings with 
	   with GTK+ 2.x.  The get_text method returns a constant pointer to
		an internal data structure rather than a conventional string.
		Since I want a conventional string, I need to copy the internal
		data structure to get it. This should probably be changed to
		use gtk_editable_get_chars(), but I don't really want to mess
		with it right now. */
	menu_file_on = g_strdup(gtk_entry_get_text(GTK_ENTRY(icon_path_on_box)));
	menu_file_off = g_strdup(gtk_entry_get_text(GTK_ENTRY(icon_path_off_box)));
	groups_on_bottom = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(group_check));
	strip_number= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(strip_check));
	write_config();
	change_menu_pixmap(LEAVE);
}

static void close_config_window(void) {
	gtk_widget_hide(GTK_WIDGET(config_win));
}

/* Stolen from Stephen Watson's infowin.c */
static int trap_client_destroy(GtkWidget *widget, GdkEvent *event,
			      gpointer data) {
  gtk_widget_hide(GTK_WIDGET(config_win));
  return TRUE;
}

void config_win_show(void) {
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(height_spin), 
	                          (gfloat) icon_height);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(width_spin), 
	                          (gfloat) icon_width);
	gtk_entry_set_text(GTK_ENTRY(icon_path_on_box), menu_file_on);
	gtk_entry_set_text(GTK_ENTRY(icon_path_off_box), menu_file_off);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(group_check), groups_on_bottom);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(strip_check), strip_number);
	
	gtk_widget_show_all(GTK_WIDGET(config_win));
}

void config_win_init(void) {
	
	GtkWidget *vbox = NULL;
	GtkWidget *hbox = NULL;
	GtkWidget *btn = NULL;

	if (config_win != NULL) return;

	/* Various formatting constants and related stuff contributed
	   by Chris Shaffer.  This form looks much better now. */

	config_win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(config_win), "ROX-Menu Options");
	/* Stolen from Stephen Watson's infowin.c */
	gtk_signal_connect(GTK_OBJECT(config_win), "delete_event", 
	                   GTK_SIGNAL_FUNC(trap_client_destroy), 
							 "WM destroy");

	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(config_win), vbox);
	
	height_spin = add_spin_entry(vbox, "Max menu icon height", 100.0, 
	                              1.0, 1.0, (gfloat) icon_height);
	width_spin = add_spin_entry(vbox, "Max menu icon width", 100.0, 1.0, 
	                              1.0, (gfloat) icon_width);
	icon_path_off_box = add_entry_box(vbox, "Normal icon", menu_file_off);
	icon_path_on_box= add_entry_box(vbox, "Mouse-over icon", menu_file_on);
	group_check = gtk_check_button_new_with_label("Put groups on bottom");
	gtk_box_pack_start(GTK_BOX(vbox), group_check, FALSE, FALSE, 5);
	strip_check = gtk_check_button_new_with_label("Strip initial number");
	gtk_box_pack_start(GTK_BOX(vbox), strip_check, FALSE, FALSE, 5);

	hbox = gtk_hbox_new(FALSE, 0);
	
	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
	btn = gtk_button_new_from_stock(GTK_STOCK_APPLY);
	gtk_signal_connect(GTK_OBJECT(btn), "clicked", 
	                   GTK_SIGNAL_FUNC(update_config), config_win);
	
	gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 2);
	btn = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
	gtk_signal_connect(GTK_OBJECT(btn), "clicked", 
	                   GTK_SIGNAL_FUNC(close_config_window), config_win);
	
	gtk_box_pack_end(GTK_BOX(hbox), btn, FALSE, FALSE, 2);
	
}

GtkWidget *add_spin_entry(GtkWidget *vbox, gchar *text, gfloat maxval, 
                          gfloat step, gfloat page, gfloat initval) {
	
	GtkWidget *hbox = NULL;
	GtkWidget *spin = NULL;
	GtkWidget *label = NULL;
	GtkObject *spin_adj = NULL;

	/* Set up the hbox and add it to the vbox. */
	hbox = gtk_hbox_new(FALSE, 10);
	gtk_box_set_homogeneous(GTK_BOX(hbox), FALSE);
	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
	/* Create the label and add it to the hbox. */
	label = gtk_label_new(text);
	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
	gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, FALSE, 0);

	/* We need to make an adjustment object for the spin button. */
	spin_adj = gtk_adjustment_new(initval, 1.0, maxval, step, page, 1.0);
	spin = gtk_spin_button_new(GTK_ADJUSTMENT(spin_adj), step, 0);
	gtk_box_pack_start(GTK_BOX(hbox), spin, TRUE, FALSE, 0);
	
	return spin;
	
}

GtkWidget *add_entry_box(GtkWidget *vbox, gchar *label, gchar *text) {

	GtkWidget *hbox = NULL;
	GtkWidget *textbox = NULL;
	GtkWidget *box_label = NULL;

	/* Set up the hbox and add it to the vbox. */
	hbox = gtk_hbox_new(FALSE, 10);
	/*gtk_box_set_homogeneous(GTK_BOX(hbox), FALSE);*/
	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
	/* Create the label and add it to the hbox. */
	box_label = gtk_label_new(label);
	gtk_label_set_justify(GTK_LABEL(box_label), GTK_JUSTIFY_LEFT);
	gtk_box_pack_start(GTK_BOX(hbox), box_label, TRUE, FALSE, 2);
	/* Add the entry and set the default text. */
	textbox = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(textbox), text);
	gtk_box_pack_end(GTK_BOX(hbox), textbox, TRUE, TRUE, 2);

	return textbox;

}
